;;; -*- auto-recompile: t -*-

;;; csound-x.el --- extending csound-sco and csound-orc major modes
;;;                 this is the installation code

;; Keywords: csound

;; This file is not part of GNU Emacs.
;; 
;; csound-x.el is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation; either version 2, or (at your option)
;; any later version.

;; csound-x.el is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with GNU Emacs; see the file COPYING.  If not, write to
;; the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.

;;; Author: Stphane Rollandin <hepta@zogotounga.net>
;;---------

;;; Commentary:
;;-------------

;;    full documentation here:
;;    http://www.zogotounga.net/comp/csoundx.html

;;; Installation:
;;---------------                   
;;
;; install Calc if necessary.
;;
;; add the following to your .emacs:
;;
;;   (setq load-path (cons "~/site-lisp/csound-x" load-path))
;;   (require 'csound-x)

;; last modified April 26, 2006


;;;======= calc (required)

;;; Commands added by calc-private-autoloads on Sat Sep 04 00:02:52 1999.
(autoload 'calc-dispatch	   "calc" "Calculator Options" t)
(autoload 'full-calc		   "calc" "Full-screen Calculator" t)
(autoload 'full-calc-keypad	   "calc" "Full-screen X Calculator" t)
(autoload 'calc-eval		   "calc" "Use Calculator from Lisp")
(autoload 'defmath		   "calc" nil t t)
(autoload 'calc			   "calc" "Calculator Mode" t)
(autoload 'quick-calc		   "calc" "Quick Calculator" t)
(autoload 'calc-keypad		   "calc" "X windows Calculator" t)
(autoload 'calc-embedded	   "calc" "Use Calc inside any buffer" t)
(autoload 'calc-embedded-activate  "calc" "Activate =>'s in buffer" t)
(autoload 'calc-grab-region	   "calc" "Grab region of Calc data" t)
(autoload 'calc-grab-rectangle	   "calc" "Grab rectangle of data" t)
(global-set-key "\e#" 'calc-dispatch)
;;; End of Calc autoloads.

;; mode algbrique par dfaut:
(setq calc-algebraic-mode t)


;;;======== (optional) MMM mode support 

(when (require 'mmm-auto nil t)
   (setq mmm-global-mode 'maybe
         mmm-submode-decoration-level 0)
   (add-to-list 'mmm-save-local-variables 'tab-stop-list)   
   (mmm-add-classes
    '((csound-orc
       :submode csound-orc-mode
       :front "<CsInstruments>"
       :front-offset (end-of-line 1)
       :back "</CsInstruments>"
       :face mmm-code-submode-face)
      (csound-sco
       :submode csound-sco-mode
       :front "<CsScore>"
       :front-offset (end-of-line 1)
       :back "</CsScore>"
       :face mmm-code-submode-face)
      (keykit
       :submode keykit-mode
       :front "<KeyPhrase[^>]*>"
       :back "</KeyPhrase>"
       :face mmm-code-submode-face)
      (embedded-elisp
       :submode emacs-lisp-mode
       :front "<ELISP>"
       :back "[;# \t]*</ELISP>"
       :face mmm-code-submode-face)))
   (dolist (class '(csound-orc csound-sco keykit embedded-elisp))
     (add-to-list 'mmm-mode-ext-classes-alist `(csound-csd-mode nil ,class)))
   (defadvice mmm-mode-on-maybe (around csoundx-around-mmm)
     "Take care of preserving the buffer modification status"
     (let ((cscsd-modflag (buffer-modified-p)))
       ad-do-it
       (set-buffer-modified-p cscsd-modflag)))
   (ad-activate 'mmm-mode-on-maybe))


;; ================== csound-x proper ======================

(require 'thingatpt)

(setq auto-mode-alist 
      (cons '("\\.\\(orc\\|udo\\)$" . csound-orc-mode) auto-mode-alist))
(autoload 'csound-orc-mode "csound-orc" "Csound Orchestra major mode." t)

(setq auto-mode-alist (cons '("\\.sco$" . csound-sco-mode) auto-mode-alist))
(autoload 'csound-sco-mode "csound-sco" "Csound Score major mode." t)

(setq auto-mode-alist (cons '("\\.csd$" . csound-csd-mode) auto-mode-alist))
(autoload 'csound-csd-mode "csound-csd" "Csound csd minor mode." t)

(defgroup csound-x nil
  "extensions to csound-orc and csound-sco modes"
  :group 'languages
  :group 'spfa
  :prefix "csoundx-")

(defgroup csound-x-applications-paths nil
  "Variables defining a path or a command line"
  :group 'spfa-paths
  :group 'csound-x)

;; these extra libraries are required here for convenience:
;; you may comment out the following lines if you do not use them
(require 'i nil t)
(require 'k nil t)
(require 'csound-lsp nil t)


;; ================== csonvenience ======================

(add-to-list 'mouse-buffer-menu-mode-groups ' ("score" . "Csound Score") t)


;; ================== this is it.
(provide 'csound-x)

;; csound-x.el ends here
